==> haskell-cmark-gfm-0.2.5-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmark-gfm
version:              0.2.5
visibility:           public
id:                   cmark-gfm-0.2.5-7YGqI6tQSKd5okzzsQJiSV
key:                  cmark-gfm-0.2.5-7YGqI6tQSKd5okzzsQJiSV
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Ashe Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.6) and does not require prior installation of the
    C library.

category:             Text
abi:                  30a1d6de3a63b3dc96b7a602a6e5c7cb
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cmark-gfm-0.2.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cmark-gfm-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.5-7YGqI6tQSKd5okzzsQJiSV
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.5-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmark-gfm
version:              0.2.5
visibility:           public
id:                   cmark-gfm-0.2.5-fO5EQb9v1uBFDzDViweb1
key:                  cmark-gfm-0.2.5-fO5EQb9v1uBFDzDViweb1
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Ashe Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.6) and does not require prior installation of the
    C library.

category:             Text
abi:                  f07703c8499cd254835a921f03d2c8f3
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cmark-gfm-0.2.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cmark-gfm-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.5-fO5EQb9v1uBFDzDViweb1
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
